@@ -250,6 +250,13 @@ static void on_cursor_notify_x(GObject* object, GParamSpec* param_spec, gpointer
 
 static gboolean on_play_button_clicked(TangleButton* tanglebutton, gpointer sequencer){
 	const gchar* name = clutter_actor_get_name (CLUTTER_ACTOR(tanglebutton));
+	
+	//If user press play-button when first sample is playing (triggering mentor to give instructions for dragging)
+	//Mentor jumps and talks sametime than track.
+	//This is fixes it:
+	jammo_mentor_speak_once(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_composing_first_click_fi.ogg");
+	jammo_mentor_shut_up(jammo_mentor_get_default());
+
 
 	if (strncmp(name,"play",4)==0)
 		{
@@ -318,7 +325,7 @@ static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer play_button
 	
 	trafficlight_dialog(CLUTTER_ACTOR(clutter_actor_get_parent(CLUTTER_ACTOR(play_button))),
                       "/opt/jammo/mentor_speech/mentor_composing_is_it_ready.ogg",
-                      "/opt/jammo/mentor_speech/mentor_composing_is_it_ready.ogg",
+                      "/opt/jammo/mentor_speech/mentor_composing_is_it_ready_idle.ogg",
                       yes_ready_clicked,play_button,
                       no_ready_clicked, NULL
                      );
@@ -480,7 +487,7 @@ static void quitting_composing(TangleActor *actor, ClutterActorBox *arg1, Clutte
 		{
 		printf("hiding -> destroy\n");
 		g_signal_handler_disconnect (actor,handler_for_view_transition);
-		clutter_actor_destroy(actor);
+		clutter_actor_destroy(CLUTTER_ACTOR(actor));
 		first_time_transition_completed=TRUE; //For next round.
 		}
 }
@@ -753,7 +760,7 @@ else { //advanced
 
 	if (variation==1)
 		{
-		background_color_code = "ggggyyyyvvvvyyyygggggggg##"; //'drumming/percussion'
+		background_color_code = "ggggyyyyvvvvyyyygggggggg#"; //'drumming/percussion'  //this is one slot shorter than another tracks!
 		tempo_factory=5;
 		}
 	if (variation==2)
@@ -862,10 +869,17 @@ if (use_two_tracks) y_offset=80;
 
 	printf("tempo_factory (time_sig): %d, beats_per_minute: %d\n",tempo_factory,beats_per_minute);
 
+	//We want operate whole time with guint64.
+	guint64 temp=60*tempo_factory;
+	guint64 one_second = 1000000000L;
+	guint64 big = temp * one_second;
+	guint64 slot_duration = big / beats_per_minute;
+
+
 	//Bottom track. Below of this there will be place for scrollbar.
 	JammoEditingTrack* editing_track_theme = jammo_editing_track_new();
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track_theme));
-	ClutterActor*	track_view = jammo_track_view_new(editing_track_theme, number_of_slots,1000000000L/beats_per_minute*60*tempo_factory, WIDTH_OF_SLOT);
+	ClutterActor*	track_view = jammo_track_view_new(editing_track_theme, number_of_slots,slot_duration, WIDTH_OF_SLOT);
 	g_object_set(track_view, "disabled-slots-begin", disabled_slots_for_begin, "disabled-slots-end", disabled_slots_for_end,NULL);
 	clutter_actor_set_reactive(track_view, TRUE);
 	g_object_set(track_view, "line-every-nth-slot", 2, NULL);
@@ -879,7 +893,7 @@ if (use_two_tracks) y_offset=80;
 	//Upper track.
 	JammoEditingTrack* editing_track_theme2 = jammo_editing_track_new();
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track_theme2));
-	ClutterActor*	track_view2 = jammo_track_view_new(editing_track_theme2, number_of_slots,1000000000L/beats_per_minute*60*tempo_factory, WIDTH_OF_SLOT);
+	ClutterActor*	track_view2 = jammo_track_view_new(editing_track_theme2, number_of_slots,slot_duration, WIDTH_OF_SLOT);
 	g_object_set(track_view2, "disabled-slots-begin", disabled_slots_for_begin, "disabled-slots-end", disabled_slots_for_end,NULL);
 	clutter_actor_set_reactive(track_view2, TRUE);
 	g_object_set(track_view2, "line-every-nth-slot", 2, NULL);
@@ -897,7 +911,7 @@ if (use_two_tracks) y_offset=80;
 	clutter_container_add_actor(CLUTTER_CONTAINER(view), scrolling_actor);
 
 
-	//printf("number_of_slots =%d  , WIDTH_OF_SLOT = %f\n",number_of_slots , WIDTH_OF_SLOT);
+
 
 	//Play-button
 	ClutterActor *play_button;
