@@ -16,6 +16,9 @@ This is the midi editor.
 
 #include "config.h"
 
+#include "../meam/jammo-meam.h"
+#include "../meam/jammo-editing-track.h"
+#include "../meam/jammo-instrument-track.h"
 
 /*
  * TODO LIST:
@@ -371,13 +374,24 @@ void note_released(ClutterActor *actor, ClutterEvent *event, gpointer data) {
 }
 
 void play_note(){
-
 	printf("play_note pressed\n");
 
-	chum_test_instrument(1); //0= flute, 1=drumkit ,2=ud
-	chum_play_sequencer();
-	chum_toggle_note_on_octave('e',1);
+	JammoSequencer* sequencer = jammo_sequencer_new();
+	JammoInstrumentTrack* instrument_track = jammo_instrument_track_new(1); //0= flute, 1=drumkit ,2=ud
+	jammo_instrument_track_set_realtime(instrument_track,TRUE);
+	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(instrument_track));
 
+	//Instrument track doesn't work if there aren't another track with one sample.
+	JammoEditingTrack* editing_track = jammo_editing_track_new();
+	JammoSample* sample;
+	gchar* filepath1 = g_strdup_printf("%s/themes/forest/loop1.wav",DATA_DIR);
+	sample = jammo_sample_new_from_file(filepath1);
+	jammo_editing_track_add_sample(editing_track, sample, 0);
+	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track));
+
+	jammo_sequencer_play(sequencer);
+
+	jammo_instrument_track_set_and_play_note_realtime(instrument_track,'e',1);
 }
 
 /*
